@@ -21,7 +21,9 @@ public:
     void logReviewedStatus(bool reviewed, const QString &user);
     void logBudgetCode(const QString &budgetCode);
     void logError(const QString &operation, const QString &message);
+    void logMetadataUpdated(const QString &user);
     void writeLog();
+    void appendToLog(const QString &folderPath, const QString &user);
 
 private:
     QString logPath;
